@@ -18,14 +18,20 @@ no warnings qw(qw utf8);
 use v5.10;
 use open qw(:std :locale);
 use utf8;
+use Config;
 use FindBin;
+use Data::Dumper;
 
 use lib "${FindBin::Bin}/../lib";
 use App::Virtualenv;
+use App::Virtualenv::Utils;
 use App::Virtualenv::Module;
+use App::Virtualenv::Piv;
 
 
-exit App::Virtualenv::Module::list();
+#exit App::Virtualenv::Module::install(force => 1, modules => ['ExtUtils::Installed']);
+exit App::Virtualenv::Piv::main(@ARGV);
+exit App::Virtualenv::perl("-I${FindBin::Bin}/../lib", "-MApp::Virtualenv::Module", "-e exit App::Virtualenv::Module::${ARGV[0]}('${ARGV[1]}');");
 =head1 AUTHOR
 
 Orkun Karaduman <orkunkaraduman@gmail.com>
